@@ -1,9 +1,8 @@
-
-
 /* provides a simple client program that reads ACPI status from the /proc 
  * filesystem
  *
  * Copyright (C) 2001  Grahame Bowland <grahame@angrygoats.net>
+ *                     Michael Meskes <meskes@debian.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,7 +27,8 @@
 /* remember to update this when making new releases */
 #define ACPI_VERSION_STRING "acpi " VERSION
 
-#define ACPI_PATH   "/proc/acpi"
+#define ACPI_PATH_PROC   "/proc/acpi"
+#define ACPI_PATH_SYS   "/sys/class"
 #define BUF_SIZE    1024
 
 #define TEMP_KELVIN     0
@@ -43,7 +43,20 @@
 #define TRUE            !(FALSE)
 #endif
 
-struct list *find_devices(char *acpi_path, char *device_type, int show_error);
+#define BATTERY 0
+#define AC_ADAPTER 1
+#define THERMAL_ZONE 2
+#define COOLING_DEV 3
+
+extern struct device
+{
+	int type;
+	char *proc;
+	char *sys;
+	char *sys_dev;
+} device[4];
+
+struct list *find_devices(char *acpi_path, int device_nr, int proc_interface);
 
 void free_devices(struct list *devices);
 
@@ -53,5 +66,7 @@ void print_ac_adapter_information(struct list *batteries, int show_empty_slots);
 
 void print_thermal_information(struct list *batteries, int show_empty_slots, int temp_units);
 
+void print_cooling_information(struct list *batteries, int show_empty_slots);
+
 #endif
 
